@@ -3,7 +3,7 @@
 This module contains the LSP diagnostics checker mode
 """
 from pyqode.core.modes import CheckerMode
-from pyqode.qt.QtCore import Signal, QTimer
+from qtpy.QtCore import Signal, QTimer
 from pyqode.language_server.backend.workers import (
     run_diagnostics,
     poll_diagnostics
@@ -71,4 +71,4 @@ class DiagnosticsMode(CheckerMode):
             .get('triggerCharacters', [])
         self.editor.modes.get(
             'CodeCompletionMode'
-        ).trigger_symbols = trigger_symbols
+        ).trigger_symbols = trigger_symbols
\ No newline at end of file
