@@ -4,7 +4,7 @@ A base class for language-server modes.
 """
 import time
 from pyqode.core.api import Mode
-from pyqode.qt import QtCore
+from qtpy import QtCore
 
 
 REQUEST_TIMEOUT = 5
@@ -31,4 +31,4 @@ class LanguageServerMode(Mode):
         
     def _on_results_available(self, results):
         
-        self._results = results
+        self._results = results
\ No newline at end of file
